@@ -1,8 +1,8 @@
 #!/usr/bin/perl -w
 
 use strict;
-use File::Temp qw/ tempfile /;
-
+use File::Temp qw/ tempdir /;
+use File::Spec;
 =head1 VARIABLES
 
 =head2 @SupportedDrivers
@@ -95,12 +95,12 @@ sub connect_handle_with_driver
 
 sub connect_sqlite {
 
-    my ( $fh, $filename ) = tempfile();
-    close($fh);
+    my $dir = tempdir(CLEANUP => 1);
+    
     my $handle = shift;
     return $handle->Connect(
         Driver   => 'SQLite',
-        Database => $filename
+        Database => File::Spec->catfile($dir => "db.sqlite")
     );
 }
 
@@ -110,6 +110,8 @@ sub connect_mysql
 	return $handle->Connect(
 		Driver => 'mysql',
 		Database => $ENV{'SB_TEST_MYSQL'},
+		Host => $ENV{'SB_TEST_MYSQL_HOST'},
+		Port => $ENV{'SB_TEST_MYSQL_PORT'},
 		User => $ENV{'SB_TEST_MYSQL_USER'} || 'root',
 		Password => $ENV{'SB_TEST_MYSQL_PASS'} || '',
 	);
@@ -121,6 +123,8 @@ sub connect_pg
 	return $handle->Connect(
 		Driver => 'Pg',
 		Database => $ENV{'SB_TEST_PG'},
+		Host => $ENV{'SB_TEST_PG_HOST'},
+		Port => $ENV{'SB_TEST_PG_PORT'},
 		User => $ENV{'SB_TEST_PG_USER'} || 'postgres',
 		Password => $ENV{'SB_TEST_PG_PASS'} || '',
 	);
